@@ -1,13 +1,5 @@
-/****************************************/
-/*					*/
-/****************************************/
-/* Start      : 13/10/2002		*/
-/* Version    : 1.00			*/
-/* Last Update: 13/10/2002		*/
-/****************************************/
-
 /*
-  Copyright (c) 2002 Stefanos Harhalakis
+  Copyright (c) 2002,2003,2004 Stefanos Harhalakis
 
   This file is part of netinfo.
 
@@ -24,37 +16,57 @@
   You should have received a copy of the GNU General Public License
   along with netinfo; if not, write to the Free Software
   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+
+  $Id: main.cc,v 1.6 2004/06/07 19:28:34 v13 Exp $
 */
 
-#include "db.h"
+#include "config.h"
+#include "conffile.h"
 #include "conf.h"
+#include "db.h"
 #include "snmp.h"
+#include "res.h"
+
+void	do_connect_db()
+{
+	int	n;
+
+	n=connect_db();
+	if (!n)
+	{
+		fprintf(stderr,"Error connecting to databse\n");
+		exit(1);
+	}
+}
 
 void	init()
 {
-	int	n;
-	
 	conf.cfg_file=CONFFILE;
 	init_conf();
-	
-	n=connect_db();
-	if (n==0)
-	{
-		fprintf(stderr,"Error connecting to database\n");
-		exit(1);
-	}
-	get_netdevs();
+
+	do_connect_db();
+
+	get_config();		// fetch parameters
+	get_netdevs();		// get devices
+	get_res_cache();	// get existing resolver cache
 }
 
 void	end()
 {
 	close_db();
+
+// Free some(?) memory
+	netdevs.ClearTable();
+	netdev_macs.Clear();
 }
 
-int main(int argn, const char *argc[])
+int main()
 {
 	init();
-	snmp_main();
+	snmp_doit();
+	check_same_ifdescr();
+	detect_netdevs();
+	update_db();
 	end();
+	do_resolve(conf.resolvers);
 }
-
